==> kubernetes-model-1.0.42-sources.jar: io/fabric8/openshift/api/model/DeploymentStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class DeploymentStrategyBuilder extends DeploymentStrategyFluentImpl<DeploymentStrategyBuilder> implements VisitableBuilder<DeploymentStrategy,DeploymentStrategyBuilder>{

     DeploymentStrategyFluent<?> fluent;
public DeploymentStrategyBuilder(){
    this(new DeploymentStrategy());
}
public DeploymentStrategyBuilder( DeploymentStrategyFluent<?> fluent ){
    this(fluent, new DeploymentStrategy());
}
public DeploymentStrategyBuilder( DeploymentStrategyFluent<?> fluent , DeploymentStrategy instance ){
    this.fluent = fluent; fluent.withAnnotations(instance.getAnnotations()); fluent.withCustomParams(instance.getCustomParams()); fluent.withLabels(instance.getLabels()); fluent.withRecreateParams(instance.getRecreateParams()); fluent.withResources(instance.getResources()); fluent.withRollingParams(instance.getRollingParams()); fluent.withType(instance.getType()); 
}
public DeploymentStrategyBuilder( DeploymentStrategy instance ){
    this.fluent = this; this.withAnnotations(instance.getAnnotations()); this.withCustomParams(instance.getCustomParams()); this.withLabels(instance.getLabels()); this.withRecreateParams(instance.getRecreateParams()); this.withResources(instance.getResources()); this.withRollingParams(instance.getRollingParams()); this.withType(instance.getType()); 
}

public EditableDeploymentStrategy build(){
    EditableDeploymentStrategy buildable = new EditableDeploymentStrategy(fluent.getAnnotations(),fluent.getCustomParams(),fluent.getLabels(),fluent.getRecreateParams(),fluent.getResources(),fluent.getRollingParams(),fluent.getType());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
DeploymentStrategyBuilder that = (DeploymentStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/openshift/api/model/DeploymentStrategyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class DeploymentStrategyBuilder extends DeploymentStrategyFluentImpl<DeploymentStrategyBuilder> implements VisitableBuilder<DeploymentStrategy,DeploymentStrategyBuilder>{

     DeploymentStrategyFluent<?> fluent;
public DeploymentStrategyBuilder(){
    this(new DeploymentStrategy());
}
public DeploymentStrategyBuilder( DeploymentStrategyFluent<?> fluent ){
    this(fluent, new DeploymentStrategy());
}
public DeploymentStrategyBuilder( DeploymentStrategyFluent<?> fluent , DeploymentStrategy instance ){
    this.fluent = fluent; fluent.withAnnotations(instance.getAnnotations()); fluent.withCustomParams(instance.getCustomParams()); fluent.withLabels(instance.getLabels()); fluent.withRecreateParams(instance.getRecreateParams()); fluent.withResources(instance.getResources()); fluent.withRollingParams(instance.getRollingParams()); fluent.withType(instance.getType()); 
}
public DeploymentStrategyBuilder( DeploymentStrategy instance ){
    this.fluent = this; this.withAnnotations(instance.getAnnotations()); this.withCustomParams(instance.getCustomParams()); this.withLabels(instance.getLabels()); this.withRecreateParams(instance.getRecreateParams()); this.withResources(instance.getResources()); this.withRollingParams(instance.getRollingParams()); this.withType(instance.getType()); 
}

public DeploymentStrategy build(){
    DeploymentStrategy buildable = new DeploymentStrategy(fluent.getAnnotations(),fluent.getCustomParams(),fluent.getLabels(),fluent.getRecreateParams(),fluent.getResources(),fluent.getRollingParams(),fluent.getType());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
DeploymentStrategyBuilder that = (DeploymentStrategyBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
